@@ -1,12 +1,14 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
+
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 // seems to be an issue with this rule and redux
@@ -33,7 +35,6 @@ import { getSourcePath } from 'temptifly'
 import apolloClient from '../../../../lib/client/apollo-client'
 import _ from 'lodash'
 import msgs from '../../../../nls/platform.properties'
-import { SEARCH_QUERY } from '../../../apollo-client/queries/SearchQueries'
 
 const existingRuleCheckbox = 'existingrule-checkbox'
 const localClusterCheckbox = 'local-cluster-checkbox'
@@ -252,26 +253,15 @@ export const summarizeOnline = (control, globalControlData, summary) => {
   }
 }
 
-const getGeneralQuery = (kind, name) => {
-  return {
-    filters: [
-      { property: 'kind', values: [kind] },
-      { property: 'name', values: [name] }
-    ]
-  }
-}
-
-const queryReturnsItems = (kind, name) => {
-  const query = getGeneralQuery(kind, name)
+const getClusterStatus = name => {
   return apolloClient
-    .search(SEARCH_QUERY, { input: [query] })
+    .getManagedClusterStatus({ clusterName: name })
     .then(response => {
-      const itemRes =
+      return (
         response &&
         response.data &&
-        response.data.searchResult[0] &&
-        response.data.searchResult[0].items
-      return !!itemRes && !!itemRes.length
+        response.data.isManagedClusterConditionAvailable
+      )
     })
     .catch(() => {
       // default to have the local-cluster managed
@@ -279,7 +269,7 @@ const queryReturnsItems = (kind, name) => {
     })
 }
 
-const enableHubSelfManagement = queryReturnsItems('cluster', 'local-cluster')
+const enableHubSelfManagement = getClusterStatus('local-cluster')
 
 const placementData = async () => [
   ////////////////////////////////////////////////////////////////////////////////////
