@@ -1,28 +1,16 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import _ from 'lodash'
-
-import React from 'react'
-import { SkeletonText } from 'carbon-components-react'
-import { Module } from 'carbon-addons-cloud-react'
+import { LOCAL_HUB_NAME } from '../../../../lib/shared/constants'
 import { getShortDateTime } from '../../../../lib/client/resource-helper'
-
-export const loadingComponent = () => {
-  return (
-    <Module className={'bx--tile search-query-card-loading'} size="single">
-      <div className="search-query-card-loading">
-        <SkeletonText />
-        <SkeletonText />
-      </div>
-    </Module>
-  )
-}
+import { createEditLink } from '../../Topology/utils/diagram-helpers'
 
 export const getSearchLinkForOneApplication = params => {
   if (params && params.name) {
@@ -30,10 +18,31 @@ export const getSearchLinkForOneApplication = params => {
     const namespace = params.namespace
       ? `%20namespace%3A${params.namespace}`
       : ''
+    const cluster = params.cluster ? `%20cluster%3A${params.cluster}` : ''
     const showRelated = params.showRelated
       ? `&showrelated=${params.showRelated}`
       : ''
-    return `/search?filters={"textsearch":"kind%3Aapplication${name}${namespace}"}${showRelated}`
+    return `/search?filters={"textsearch":"kind%3Aapplication${name}${namespace}${cluster}"}${showRelated}`
+  }
+  return ''
+}
+
+export const getSearchLinkForArgoApplications = source => {
+  if (source) {
+    let textsearch = 'kind:application apigroup:argoproj.io'
+    for (const [key, value] of Object.entries(source)) {
+      textsearch = `${textsearch} ${key}:${value}`
+    }
+    return `/search?filters={"textsearch":"${encodeURIComponent(textsearch)}"}`
+  }
+  return ''
+}
+
+export const getRepoTypeForArgoApplication = source => {
+  if (source && source.path) {
+    return 'git'
+  } else if (source && source.chart) {
+    return 'helmrepo'
   }
   return ''
 }
@@ -45,6 +54,7 @@ const getSubCardData = (subData, node) => {
   let gitPath = ''
   let packageName = ''
   let packageFilterVersion = ''
+  let bucketPath = ''
   let timeWindowType = ''
   let timeWindowDays = ''
   let timeWindowTimezone = ''
@@ -79,6 +89,11 @@ const getSubCardData = (subData, node) => {
   )
   packageName = _.get(subData, 'spec.name', '')
   packageFilterVersion = _.get(subData, 'spec.packageFilter.version', '')
+  bucketPath = _.get(subData, [
+    'metadata',
+    'annotations',
+    'apps.open-cluster-management.io/bucket-path'
+  ])
   timeWindowType = _.get(subData, 'spec.timewindow.windowtype', 'none')
   timeWindowDays = _.get(subData, 'spec.timewindow.daysofweek', '')
   timeWindowTimezone = _.get(subData, 'spec.timewindow.location', '')
@@ -109,6 +124,7 @@ const getSubCardData = (subData, node) => {
     gitPath: gitPath,
     package: packageName,
     packageFilterVersion: packageFilterVersion,
+    bucketPath: bucketPath,
     timeWindowType: timeWindowType,
     timeWindowDays: timeWindowDays,
     timeWindowTimezone: timeWindowTimezone,
@@ -121,26 +137,28 @@ export const getAppOverviewCardsData = (
   topologyData,
   appName,
   appNamespace,
-  targetLink,
   locale
 ) => {
   // Get app details only when topology data is properly loaded for the selected app
   const appData = _.get(topologyData, 'activeFilters.application')
   if (
     !selectedAppData ||
-    selectedAppData.status !== 'DONE' ||
+    (selectedAppData.status !== 'DONE' && selectedAppData.status !== 'ERROR') || //allow search microservice to not be found
     topologyData.status !== 'DONE' ||
     topologyData.detailsLoaded !== true
   ) {
     return {
-      appName: appName,
-      appNamespace: appNamespace,
       creationTimestamp: -1,
+      lastSyncedTimestamp: -1,
       remoteClusterCount: -1,
       localClusterDeploy: false,
       nodeStatuses: -1,
-      targetLink: targetLink,
-      subsList: -1
+      subsList: -1,
+      isArgoApp: false,
+      argoSource: -1,
+      destinationNs: -1,
+      destinationCluster: '',
+      editArgoSetLink: ''
     }
   }
 
@@ -151,10 +169,17 @@ export const getAppOverviewCardsData = (
     appData.name === appName &&
     appData.namespace === appNamespace
   ) {
+    let apiGroup = 'app.k8s.io'
     let creationTimestamp = ''
+    let lastSyncedTimestamp = ''
+    let destinationNs = ''
+    let destinationCluster = ''
     const nodeStatuses = { green: 0, yellow: 0, red: 0, orange: 0 }
     const subsList = []
-
+    let clusterNames = []
+    let argoSource = {}
+    let isArgoApp = false
+    let editArgoSetLink = ''
     let clusterData = {
       remoteCount: 0,
       isLocal: false
@@ -177,11 +202,75 @@ export const getAppOverviewCardsData = (
           locale
         )
         const allSubscriptions = _.get(node, 'specs.allSubscriptions', [])
+        let lastSynced = ''
         allSubscriptions.forEach(subs => {
+          if (!lastSynced) {
+            lastSynced = _.get(
+              subs,
+              'metadata.annotations["apps.open-cluster-management.io/manual-refresh-time"]',
+              ''
+            )
+          }
           subsList.push(getSubCardData(subs, node))
         })
+        lastSyncedTimestamp = getShortDateTime(lastSynced, locale)
+
+        isArgoApp =
+          _.get(node, ['specs', 'raw', 'apiVersion'], '').indexOf('argo') !==
+          -1
+        if (isArgoApp) {
+          // set argocd api group
+          apiGroup = 'argoproj.io'
+          // set argo app cluster names
+          clusterNames = _.get(node, ['specs', 'clusterNames'], [])
+          argoSource = _.get(node, ['specs', 'raw', 'spec', 'source'], {})
+          lastSyncedTimestamp = getShortDateTime(
+            _.get(node, ['specs', 'raw', 'status', 'reconciledAt'], ''),
+            locale
+          )
+
+          // set destination namespace and cluster
+          const relatedApps = _.get(node, ['specs', 'relatedApps'], [])
+          relatedApps.filter(app => {
+            if (
+              app.name === appName &&
+              app.namespace === appNamespace &&
+              app.destinationNamespace
+            ) {
+              destinationNs = app.destinationNamespace
+              destinationCluster = app.destinationName
+                ? app.destinationName
+                : app.destinationCluster ? app.destinationCluster : ''
+            }
+          })
+
+          const ownerReferences = _.get(
+            node,
+            'specs.raw.metadata.ownerReferences',
+            []
+          )
+          if (ownerReferences.length > 0) {
+            const res = {
+              cluster: node.cluster || LOCAL_HUB_NAME,
+              namespace: appNamespace,
+              name: _.get(ownerReferences[0], 'name', 'unknown'),
+              apiversion: 'v1alpha1',
+              kind: _.get(ownerReferences[0], 'kind', 'unknown'),
+              specs: {
+                raw: {
+                  apiVersion: _.get(
+                    ownerReferences[0],
+                    'apiVersion',
+                    'argoproj.io/v1alpha1'
+                  )
+                }
+              }
+            }
+            editArgoSetLink = createEditLink(res)
+          }
+        }
       }
-      //get pulse for all objects generated from a ddeployable
+      //get pulse for all objects generated from a deployable
       if (
         _.get(node, 'id', '').indexOf('--deployable') !== -1 &&
         _.get(node, 'specs.pulse')
@@ -191,25 +280,35 @@ export const getAppOverviewCardsData = (
       }
     })
     return {
-      appName: appName,
-      appNamespace: appNamespace,
       creationTimestamp: creationTimestamp,
+      lastSyncedTimestamp: lastSyncedTimestamp,
       remoteClusterCount: clusterData.remoteCount,
       localClusterDeploy: clusterData.isLocal,
       nodeStatuses: nodeStatuses,
-      targetLink: targetLink,
-      subsList: subsList
+      subsList: subsList,
+      apiGroup: apiGroup,
+      clusterNames: clusterNames,
+      isArgoApp: isArgoApp,
+      argoSource: argoSource,
+      destinationNs: destinationNs,
+      destinationCluster: destinationCluster,
+      editArgoSetLink: editArgoSetLink
     }
   } else {
     return {
-      appName: appName,
-      appNamespace: appNamespace,
       creationTimestamp: -1,
+      lastSyncedTimestamp: -1,
       remoteClusterCount: -1,
       localClusterDeploy: false,
       nodeStatuses: -1,
-      targetLink: targetLink,
-      subsList: -1
+      subsList: -1,
+      apiGroup: 'app.k8s.io',
+      clusterNames: [],
+      isArgoApp: false,
+      argoSource: -1,
+      destinationNs: -1,
+      destinationCluster: '',
+      editArgoSetLink: ''
     }
   }
 }
