@@ -1,14 +1,12 @@
-/*******************************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
-import lodash from "lodash";
+import _ from "lodash";
 import moment from "moment";
 import {
   RESOURCE_TYPES,
   transform,
   createEditLink,
-  getLabelsToList,
   getAge,
   getResourceType,
   getClusterCount,
@@ -126,7 +124,7 @@ describe("transform", () => {
 
   it("return transformFunction value", () => {
     const transformFun = (resource, locale, key, isSearch) => {
-      let value = lodash.get(resource, key);
+      let value = _.get(resource, key);
       return "transfomred " + value;
     };
     const key = {
@@ -139,115 +137,6 @@ describe("transform", () => {
   });
 });
 
-describe("getLabelsToList", () => {
-  const item = {
-    name: "guestbook-app",
-    namespace: "default",
-    dashboard: "",
-    selfLink:
-      "/apis/app.k8s.io/v1beta1/namespaces/default/applications/guestbook-app",
-    _uid: "local-cluster/0221dae9-b6b9-40cb-8cba-473011a750e0",
-    created: "2020-04-06T22:27:05Z",
-    apigroup: "app.k8s.io",
-    cluster: "local-cluster",
-    kind: "application",
-    label: "",
-    _hubClusterResource: "true",
-    _rbac: "default_app.k8s.io_applications",
-    related: [
-      {
-        kind: "placementrule",
-        items: [
-          {
-            kind: "placementrule",
-            name: "dev-clusters",
-            namespace: "default",
-            selfLink:
-              "/apis/apps.open-cluster-management.io/v1/namespaces/default/placementrules/dev-clusters",
-            apigroup: "apps.open-cluster-management.io",
-            apiversion: "v1",
-            _hubClusterResource: "true",
-            _rbac: "default_apps.open-cluster-management.io_placementrules",
-            _uid: "local-cluster/a4d4460d-5a08-4594-9161-6fb3c8b3efea",
-            created: "2020-04-06T22:26:46Z",
-            cluster: "local-cluster"
-          }
-        ],
-        __typename: "SearchRelatedResult"
-      }
-    ],
-    custom: {
-      name: {
-        key: null,
-        ref: null,
-        props: {
-          to: "/multicloud/applications/default/guestbook-app",
-          children: "guestbook-app",
-          replace: false
-        },
-        _owner: null,
-        _store: {}
-      },
-      clusters: 0,
-      subscriptions: {
-        type: "ul",
-        key: null,
-        ref: null,
-        props: {
-          children: [
-            {
-              key: "1",
-              ref: null,
-              props: { labelText: 0 },
-              _owner: null,
-              _store: {}
-            },
-            false,
-            {
-              key: "2",
-              ref: null,
-              props: {
-                labelText: 0,
-                iconName: "failed-status",
-                description: "Failed"
-              },
-              _owner: null,
-              _store: {}
-            },
-            {
-              key: "3",
-              ref: null,
-              props: {
-                labelText: 0,
-                iconName: "no-status",
-                description: "No status"
-              },
-              _owner: null,
-              _store: {}
-            }
-          ]
-        },
-        _owner: null,
-        _store: {}
-      },
-      created: "20 hours ago"
-    }
-  };
-  const locale = "en-US";
-
-  it("return resourceKey value", () => {
-    const labelsKey = "selector";
-    const output = getLabelsToList(item, locale, labelsKey);
-    expect(output).toEqual("-");
-  });
-
-  it("return undefined value", () => {
-    const labelsKey = "annotations";
-    const output = getLabelsToList(item, locale, labelsKey);
-    expect(output).toEqual("-");
-  });
-});
-
 describe("getAge", () => {
   const item = {
     name: "guestbook-app",
@@ -444,6 +333,20 @@ describe("getClusterCount", () => {
       })
     ).toMatchSnapshot();
   });
+  it("handles Argo app properties", () => {
+    expect(
+      getClusterCount({
+        locale: "",
+        remoteCount: 1,
+        localPlacement: true,
+        name: "app",
+        namespace: "thenamespace",
+        kind: "application",
+        apigroup: "argoproj.io",
+        clusterNames: ["local-cluster", "ui-dev-remote"]
+      })
+    ).toMatchSnapshot();
+  });
 });
 
 describe("getClusterCountString", () => {
@@ -513,6 +416,22 @@ describe("getSearchLink", () => {
       '/search?filters={"textsearch":"name%3Atesting"}&showrelated=subscriptions'
     );
   });
+
+  it("handles array properties", () => {
+    expect(
+      getSearchLink({
+        properties: {
+          name: ["helloworld-local", "helloworld-remote"],
+          namespace: ["argocd", "openshift-gitops"],
+          kind: "application",
+          apigroup: "argoproj.io"
+        },
+        showRelated: "cluster"
+      })
+    ).toEqual(
+      '/search?filters={"textsearch":"name%3Ahelloworld-local%2Chelloworld-remote%20namespace%3Aargocd%2Copenshift-gitops%20kind%3Aapplication%20apigroup%3Aargoproj.io"}&showrelated=cluster'
+    );
+  });
 });
 
 describe("getEditLink should return editLink", () => {
