@@ -1,4 +1,5 @@
-var _curry2 = /*#__PURE__*/require('./internal/_curry2');
+var _curry2 = require('./internal/_curry2');
+
 
 /**
  * Takes two arguments, `fst` and `snd`, and returns `[fst, snd]`.
@@ -16,9 +17,4 @@ var _curry2 = /*#__PURE__*/require('./internal/_curry2');
  *
  *      R.pair('foo', 'bar'); //=> ['foo', 'bar']
  */
-
-
-var pair = /*#__PURE__*/_curry2(function pair(fst, snd) {
-  return [fst, snd];
-});
-module.exports = pair;
\ No newline at end of file
+module.exports = _curry2(function pair(fst, snd) { return [fst, snd]; });
